DialogEntry class
Constructors
- DialogEntry({required String id, required Widget dialog, DialogPriority priority = DialogPriority.medium, bool isFixed = false, bool canBeClosed()?})
Properties
- canBeClosed → bool Function()?
-
final
- dialog → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isFixed → bool
-
final
- priority → DialogPriority
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited