IDialog class abstract
- Implementers
Constructors
- IDialog()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllDialogs(
) → void -
closeDialog(
String id) → void -
isDialogOpen(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required String id, String? title, String? content, List< Widget> ? actions, DialogPriority priority, bool isFixed, bool canBeClosed()?, Widget? customDialog}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited