PriorityDialog class
- Implemented types
Constructors
- PriorityDialog({})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllDialogs(
) → void -
override
-
closeDialog(
String id) → void -
override
-
isDialogOpen(
) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required String id, String? title, String? content, List< Widget> ? actions, DialogPriority priority = DialogPriority.medium, bool isFixed = false, bool canBeClosed()?, Widget? customDialog}) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited